package com.wd.workoffice.ui.activity.bat.approval;

import android.text.TextUtils;
import android.view.View;

import com.alibaba.fastjson.JSON;
import com.chad.library.adapter.base.BaseQuickAdapter;
import com.scwang.smartrefresh.layout.SmartRefreshLayout;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.ApprovalBean;
import com.wd.workoffice.bean.event.CheckSendEvent;
import com.wd.workoffice.bean.workEnum.OrderType;
import com.wd.workoffice.bean.workEnum.PagePermissionType;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.activity.bat.order.CrucibleOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.order.InsideOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.order.OutOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.order.ProductOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.order.SaleOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.order.SupplierOrderDetailActivity;
import com.wd.workoffice.ui.activity.bat.work.WorkContactsOpenTicketActivity;
import com.wd.workoffice.ui.activity.bat.work.WorkFinancialReceiveTicketActivity;
import com.wd.workoffice.ui.activity.bat.work.WorkFinancialTicketActivity;
import com.wd.workoffice.ui.activity.bat.work.WorkProDetailActivity;
import com.wd.workoffice.ui.adapter.ApprovalAdapter;
import com.wd.workoffice.util.WorkUtils;

import org.greenrobot.eventbus.EventBus;
import org.greenrobot.eventbus.Subscribe;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.Observable;
import io.reactivex.disposables.Disposable;

/**
 * 审核列表
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkApprovalActivity extends WorkToolBarActivity {


    @BindView(R.id.rv_data)
    RecyclerView rvData;
    @BindView(R.id.srl_refresh)
    SmartRefreshLayout srlRefresh;
    private String state;
    private int page = 1;
    private Map<String, Object> param;
    private ApprovalAdapter dataAdapter;
    private List<ApprovalBean.RecordsBean> dataList;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        rvData.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
    }


    @Override
    protected void initData() {
        param = WorkUtils.pageKey();
        param.put("statusFilter", getIntent().getStringExtra("status"));
        param.put("linkUserStatus", getIntent().getStringExtra("status"));
//        param.put("orderId", orderId);
        page = 1;
        param.put("current", page);
        dataList = new ArrayList<>();
        dataAdapter = new ApprovalAdapter(R.layout.item_approval, dataList);
        dataAdapter.bindToRecyclerView(rvData);
        dataAdapter.setEmptyView(R.layout.view_empty_content, rvData);
        getData();
    }


    private void getData() {
        Observable<BaseBean> observable;
        if (TextUtils.equals(getIntent().getStringExtra("type"), "1")) {//待审核
            observable = RtfUtils.getRtf().bizMeApproval(param);
        } else {
            observable = RtfUtils.getRtf().bizApproval(param);
        }
        observable.compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                List<ApprovalBean.RecordsBean> getList = JSON.parseObject(data.getData().toString(), ApprovalBean.class).getRecords();
                if (page == 1) {
                    srlRefresh.finishRefresh();
                    dataList.clear();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                    dataAdapter.loadMoreComplete();
                } else {
                    dataAdapter.loadMoreComplete();
                    dataList.addAll(getList);
                    dataAdapter.notifyDataSetChanged();
                }
                if (getList.size() == 0) {
                    dataAdapter.loadMoreEnd();
                } else {
                    page++;
                }
            }
        });
    }

    @Override
    protected void initEvent() {
        srlRefresh.setOnRefreshListener(refreshLayout -> {
            page = 1;
            param.put("current", page);
            getData();
        });
        dataAdapter.setOnLoadMoreListener(() -> {
            param.put("current", page);
            getData();
        }, rvData);
        dataAdapter.setOnItemClickListener(new BaseQuickAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(BaseQuickAdapter adapter, View view, int position) {
                ApprovalBean.RecordsBean approval = dataList.get(position);
                approvalGoNext(approval);
            }
        });
    }

    private void approvalGoNext(ApprovalBean.RecordsBean approval) {
        if (TextUtils.equals("SO_INVOICE", approval.getFlowCode()) ||
                TextUtils.equals("PO_INVOICE", approval.getFlowCode()) || TextUtils.equals("AO_INVOICE", approval.getFlowCode())) {
            startActivity(WorkFinancialTicketActivity.class);
        } else if (TextUtils.equals("PO_RECEIPT_INVOICE", approval.getFlowCode()) ||
                TextUtils.equals("FO_RECEIPT_INVOICE", approval.getFlowCode())) {
            startActivity(WorkFinancialReceiveTicketActivity.class);
        } else {
            if (TextUtils.equals(OrderType.SALE.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.SALE_ORDER_DETAIL.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(SaleOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals(OrderType.BUILD.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.AO_PACKAGE_DETAILS.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(ProductOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals(OrderType.OUT_BUY.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.PO_PURCHASE_DETAILS.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(OutOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals(OrderType.IN.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.IO_INSIDE_DETAILS.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(InsideOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals(OrderType.SUPPLIER.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.FO_SUPPLIER_DETAILS.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(SupplierOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals(OrderType.CRUCIBLE.getCode(), approval.getOrderType())) {
                if (!WorkUtils.hasPermission(PagePermissionType.CO_CRUCIBLE_DETAILS.getPermission())) {
                    toast(R.string.permission);
                    return;
                }
                startActivity(CrucibleOrderDetailActivity.class,
                        "identity", "1",
                        "id", approval.getOrderId());
            } else if (TextUtils.equals("PM", approval.getOrderType())) {
                startActivity(WorkProDetailActivity.class,
                        "id", approval.getId() + "");
            }
        }
    }


    @Override
    protected int layoutId() {
        return R.layout.fg_work_contacts;
    }

    @Override
    public void onStart() {
        super.onStart();
        EventBus.getDefault().register(this);
    }

    @Override
    public void onStop() {
        super.onStop();
        EventBus.getDefault().unregister(this);
    }

    @Subscribe
    public void refresh(CheckSendEvent event) {
        page = 1;
        param.put("current", page);
        getData();
    }

}
