package com.wd.workoffice.ui.activity.bat.work;

import android.os.Bundle;
import android.text.TextUtils;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.alibaba.fastjson.JSON;
import com.wd.workoffice.R;
import com.wd.workoffice.app.BaseBean;
import com.wd.workoffice.app.WorkToolBarActivity;
import com.wd.workoffice.bean.TicketBean;
import com.wd.workoffice.bean.TicketDetailBean;
import com.wd.workoffice.bean.event.CheckTicketEvent;
import com.wd.workoffice.bean.workEnum.PagePermissionType;
import com.wd.workoffice.retrofit.RtfUtils;
import com.wd.workoffice.retrofit.WorkObserver;
import com.wd.workoffice.ui.adapter.WorkFinancialTicketDetailAdapter;
import com.wd.workoffice.util.WorkUtils;

import org.greenrobot.eventbus.EventBus;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import androidx.appcompat.app.AlertDialog;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import flexible.xd.android_base.network.rtfhttp.Transformer;
import io.reactivex.Observable;
import io.reactivex.disposables.Disposable;

/**
 * 工作台 - 收票详情
 * author : flexible
 * email : lgd19940421@163.com
 * github: https://github.com/FlexibleXd
 **/
public class WorkFinancialReceiveTicketDetailActivity extends WorkToolBarActivity {
    @BindView(R.id.tv_refuse)
    TextView tvRefuse;
    @BindView(R.id.tv_agree)
    TextView tvAgree;
    @BindView(R.id.ll_bottom)
    LinearLayout llBottom;
    @BindView(R.id.tv_client)
    TextView tvClient;
    @BindView(R.id.tv_price)
    TextView tvPrice;
    @BindView(R.id.tv_tax)
    TextView tvTax;
    @BindView(R.id.tv_remark)
    TextView tvRemark;
    @BindView(R.id.rv_data)
    RecyclerView rvData;
    @BindView(R.id.tv_desc)
    TextView tvDesc;
    @BindView(R.id.tv_check_person)
    TextView tvCheckPerson;
    @BindView(R.id.tv_check_time)
    TextView tvCheckTime;
    @BindView(R.id.tv_check_remark)
    TextView tvCheckRemark;
    @BindView(R.id.tv_check_status)
    TextView tvCheckStatus;
    @BindView(R.id.ll_check)
    LinearLayout llCheck;
    private List<TicketDetailBean> dataList;
    private WorkFinancialTicketDetailAdapter dataAdapter;
    private Map<String, Object> param;
    private String orderType;

    @Override
    protected void initView() {
        ButterKnife.bind(this);
        tvDesc.setText("所属供应商");
        rvData.setLayoutManager(new LinearLayoutManager(this, RecyclerView.VERTICAL, false));
    }

    @Override
    protected void initData() {
        TicketBean.RecordsBean info = JSON.parseObject(getIntent().getStringExtra("info"), TicketBean.RecordsBean.class);
        getData(info.getId() + "");
        tvClient.setText(info.getSupplierName());
        tvPrice.setText(String.valueOf(info.getInvoiceSum()));
        tvTax.setText(String.valueOf(info.getTax()));
        tvRemark.setText(info.getApplyRemark());
        tvCheckPerson.setText(info.getExamedByName());
        tvCheckTime.setText(info.getUpdatedTime());
        tvCheckRemark.setText(info.getAuditRemark());
        if (TextUtils.equals(info.getStatus(), "0")) {
            llBottom.setVisibility(View.VISIBLE);
            llCheck.setVisibility(View.GONE);
        } else {
            llBottom.setVisibility(View.GONE);
            llCheck.setVisibility(View.VISIBLE);
        }
        dataList = new ArrayList<>();
        dataAdapter = new WorkFinancialTicketDetailAdapter(R.layout.item_ticket_detail, dataList);
        dataAdapter.bindToRecyclerView(rvData);
        param = new HashMap<>();
        param.put("id", info.getId());
        orderType = getIntent().getStringExtra("type");
        changePermission();
    }

    private void getData(String id) {
        RtfUtils.getRtf().ticketReceiveDetail(id).compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {


            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                List<TicketDetailBean> dataBean = JSON.parseArray(data.getData().toString(), TicketDetailBean.class);
                dataList.addAll(dataBean);
                dataAdapter.notifyDataSetChanged();
            }
        });
    }

    @Override
    protected void initEvent() {
    }

    @Override
    protected int layoutId() {
        return R.layout.activity_work_financial_ticket_detail;
    }


    @OnClick({R.id.tv_refuse, R.id.tv_agree})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.tv_refuse:
                checkDialog(2);
                break;
            case R.id.tv_agree:
                checkDialog(1);
                break;
        }
    }

    private void checkDialog(int status) {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        View view = LayoutInflater.from(this).inflate(R.layout.view_check, null);
        TextView tvOk = view.findViewById(R.id.tv_ok);
        TextView tvDesc = view.findViewById(R.id.tv_desc);
        tvDesc.setText(status == 1 ? "通过" : "拒绝");
        TextView tvNum = view.findViewById(R.id.tv_num);
        TextView tvCancel = view.findViewById(R.id.tv_cancel);
        EditText etRemark = view.findViewById(R.id.et_content);
        WorkUtils.addNumListener(etRemark, tvNum);
        builder.setView(view);
        AlertDialog addCartDialog = builder.create();
        tvOk.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (status != 1 && TextUtils.isEmpty(etRemark.getText().toString())) {
                    toast("请填写备注");
                    return;
                }
                check(status, etRemark.getText().toString());
                addCartDialog.dismiss();
            }
        });
        tvCancel.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                addCartDialog.dismiss();
            }
        });
        addCartDialog.show();
    }


    private void check(int status, String remark) {
        param.put("status", status);
        param.put("auditRemark", remark);
        Observable<BaseBean> baseBeanObservable;
        if (TextUtils.equals(orderType, "供应订单")) {
            baseBeanObservable = RtfUtils.getRtf().receiveFoExam(WorkUtils.convertMapToBody(param));
        } else if (TextUtils.equals(orderType, "外采购订单")) {
            baseBeanObservable = RtfUtils.getRtf().receivePoExam(WorkUtils.convertMapToBody(param));
        } else {
            baseBeanObservable = RtfUtils.getRtf().receiveFoExam(WorkUtils.convertMapToBody(param));
        }
        baseBeanObservable.compose(Transformer.schedule()).subscribe(new WorkObserver<BaseBean>() {
            @Override
            public void doOnSubscribe(Disposable d) {
            }

            @Override
            public void onFail(String errorMsg) {
                hideLoading();
                toast(errorMsg);
            }

            @Override
            public void onSuccess(BaseBean data) {
                hideLoading();
                if (data.getCode() != 0) {
                    toast(data.getMessage());
                    return;
                }
                toast("操作成功");
                EventBus.getDefault().post(new CheckTicketEvent());
                finish();
            }
        });
    }

    private void changePermission() {
        boolean hasPermission = true;
        if (TextUtils.equals(orderType, "供应订单")) {
            hasPermission = WorkUtils.hasPermission(PagePermissionType.FO_RECEIPT_AUDIT.getPermission());
        } else if (TextUtils.equals(orderType, "外采购订单")) {
            hasPermission = WorkUtils.hasPermission(PagePermissionType.PO_RECEIPT_AUDIT.getPermission());
        }
        if (!hasPermission) {
            tvRefuse.setVisibility(View.GONE);
            tvAgree.setVisibility(View.GONE);
        }
    }

}
